earthUI-package: earthUI: Interactive 'shiny' GUI for the 'earth' Package

earthUI-packageR Documentation

earthUI: Interactive 'shiny' GUI for the 'earth' Package

Description

Provides a 'shiny'-based graphical user interface for the 'earth' package, enabling interactive building and exploration of Multivariate Adaptive Regression Splines (MARS) models. Features include data import from CSV and 'Excel' files, automatic detection of categorical variables, interactive control of interaction terms via an allowed matrix, comprehensive model diagnostics with variable importance and partial dependence plots, and publication-quality report generation via 'Quarto'.

Author(s)

Maintainer: William Craytor bcraytor@proton.me

See Also

Useful links:


earthUI documentation built on March 26, 2026, 1:07 a.m.