View source: R/format_results.R
| format_variable_importance | R Documentation |
Extracts variable importance scores from a fitted earth model using
earth::evimp().
format_variable_importance(earth_result)
earth_result |
An object of class |
A data frame with columns variable, nsubsets, gcv, and rss,
sorted by overall importance (nsubsets).
result <- fit_earth(mtcars, "mpg", c("cyl", "disp", "hp", "wt"))
format_variable_importance(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.