plot_correlation_matrix: Plot correlation matrix

View source: R/plot_results.R

plot_correlation_matrixR Documentation

Plot correlation matrix

Description

Creates a heatmap of pairwise correlations among the target variable and numeric predictors, with cells colored by degree of correlation and values printed in each cell.

Usage

plot_correlation_matrix(earth_result)

Arguments

earth_result

An object of class "earthUI_result" as returned by fit_earth().

Value

A ggplot2::ggplot object.

Examples


result <- fit_earth(mtcars, "mpg", c("cyl", "disp", "hp", "wt"))
plot_correlation_matrix(result)


earthUI documentation built on March 26, 2026, 1:07 a.m.